# ascmii: "Ask Me"

## ASCII Messenger

## Installation

Install using pip:
```
pip install ascmii
```

## Usage

Coming soon.

## Alternatives

- desklank
- lanku

## Author

Created by Shawn A. Wilson [lannocc@yahoo.com] aka LANNOCC.

